@@ -17,7 +17,10 @@
 #' rp2 <- rfPermute(Species ~ ., iris, ntree = 50, norm.votes = FALSE, nrep = 100)
 #' rp3 <- rfPermute(Species ~ ., iris, ntree = 50, norm.votes = FALSE, nrep = 100)
 #' rp.all <- rp.combine(rp1, rp2, rp3)
-#' plot(rp.all)
+#' 
+#' layout(matrix(1:6, nrow = 2))
+#' plotNull(rp.all) 
+#' layout(matrix(1))
 #' 
 #' @importFrom abind abind
 #' @importFrom randomForest combine
@@ -34,6 +37,6 @@ rp.combine <- function(...) {
   }, simplify = FALSE)
   rf$pval <- .calcImpPval(rf)
   
-  class(rf) <- c("rfPermute", "randomForest")
+  class(rf) <- class(rp.list[[1]])
   return(rf)  
 }
\ No newline at end of file
